==> mastercard_spendalerts-1.0.2-py2-none-any.whl: mastercardspendalerts/crossborder.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Crossborder(BaseObject):
	"""
	
	"""

	__config = {
		
		"c122f4db-3dff-4288-bd70-511ef499840e" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/crossborder", "delete", [], []),
		
		"cac75bdd-3425-4c02-93d0-c8239be0fc1a" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/crossborder", "query", [], []),
		
		"f76f2577-84d5-4285-a610-0c759192de01" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/crossborder", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Crossborder by id

		@param str id
		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("c122f4db-3dff-4288-bd70-511ef499840e", Crossborder(mapObj))

	def delete(self):
		"""
		Delete object of type Crossborder

		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("c122f4db-3dff-4288-bd70-511ef499840e", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Crossborder by id and optional criteria
		@param type criteria
		@return Crossborder object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("cac75bdd-3425-4c02-93d0-c8239be0fc1a", Crossborder(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Crossborder

		@param Dict mapObj, containing the required parameters to create a new object
		@return Crossborder of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("f76f2577-84d5-4285-a610-0c759192de01", Crossborder(mapObj))

==> mastercard_spendalerts-1.0.6-py2-none-any.whl: mastercardspendalerts/crossborder.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardspendalerts import ResourceConfig

class Crossborder(BaseObject):
	"""
	
	"""

	__config = {
		
		"64ed4050-6d49-4fb7-8048-2888c60d7fc2" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/crossborder", "delete", [], []),
		
		"1a548c83-3708-4dc2-ac0f-a4f870670f4b" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/crossborder", "query", [], []),
		
		"08431782-a162-4479-ab71-04a0a759b5c7" : OperationConfig("/issuer/v1/card/{uuid}/controls/alerts/crossborder", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Crossborder by id

		@param str id
		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("64ed4050-6d49-4fb7-8048-2888c60d7fc2", Crossborder(mapObj))

	def delete(self):
		"""
		Delete object of type Crossborder

		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("64ed4050-6d49-4fb7-8048-2888c60d7fc2", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Crossborder by id and optional criteria
		@param type criteria
		@return Crossborder object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("1a548c83-3708-4dc2-ac0f-a4f870670f4b", Crossborder(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Crossborder

		@param Dict mapObj, containing the required parameters to create a new object
		@return Crossborder of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("08431782-a162-4479-ab71-04a0a759b5c7", Crossborder(mapObj))
